@@ -14,7 +14,6 @@ Usage::
 from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_personalize_runtime.type_defs import (
     GetPersonalizedRankingResponseTypeDef,
@@ -24,15 +23,23 @@ from mypy_boto3_personalize_runtime.type_defs import (
 __all__ = ("PersonalizeRuntimeClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    InvalidInputException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    InvalidInputException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
 
 
 class PersonalizeRuntimeClient:
     """
-    [PersonalizeRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [PersonalizeRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
     """
 
     meta: ClientMeta
@@ -40,7 +47,7 @@ class PersonalizeRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -51,7 +58,7 @@ class PersonalizeRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
         """
 
     def get_personalized_ranking(
@@ -63,7 +70,7 @@ class PersonalizeRuntimeClient:
         filterArn: str = None,
     ) -> GetPersonalizedRankingResponseTypeDef:
         """
-        [Client.get_personalized_ranking documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Client.get_personalized_ranking documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
         """
 
     def get_recommendations(
@@ -76,5 +83,5 @@ class PersonalizeRuntimeClient:
         filterArn: str = None,
     ) -> GetRecommendationsResponseTypeDef:
         """
-        [Client.get_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Client.get_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
         """
